summaryrefslogtreecommitdiffstats
path: root/kplato/kpttask.h
diff options
context:
space:
mode:
Diffstat (limited to 'kplato/kpttask.h')
-rw-r--r--kplato/kpttask.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kplato/kpttask.h b/kplato/kpttask.h
index 2d3776db..55abd23f 100644
--- a/kplato/kpttask.h
+++ b/kplato/kpttask.h
@@ -244,7 +244,7 @@ public:
/// Calculate critical path
virtual bool calcCriticalPath(bool fromEnd);
/// Set current schedule to schedule with identity id, for me nd my tqchildren
virtual void setCurrentSchedule(long id);
virtual bool effortMetError() const;
@@ -296,7 +296,7 @@ private:
#ifndef NDEBUG
public:
- void printDebug(bool tqchildren, TQCString indent);
+ void printDebug(bool children, TQCString indent);
#endif
};
@@ -244,7 +244,7 @@ public:
/// Calculate critical path
virtual bool calcCriticalPath(bool fromEnd);
- /// Set current schedule to schedule with identity id, for me nd my tqchildren
+ /// Set current schedule to schedule with identity id, for me nd my children
virtual void setCurrentSchedule(long id);
virtual bool effortMetError() const;